@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/tagreader.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/tagreader.cpp   3.3.7   edited Feb 20 2006 $
 **
 ** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
@@ -16,15 +16,15 @@
 int main( int argc, char **argv )
 {
     if ( argc < 2 ) {
-	fprintf( stderr, "Usage: %s <xmlfile>\n", argv[0] );
+	fprintf( stderr, "Usage: %s <xmlfile> [<xmlfile> ...]\n", argv[0] );
 	return 1;
     }
+    StructureParser handler;
+    QXmlSimpleReader reader;
+    reader.setContentHandler( &handler );
     for ( int i=1; i < argc; i++ ) {
-        StructureParser handler;
         QFile xmlFile( argv[i] );
         QXmlInputSource source( &xmlFile );
-        QXmlSimpleReader reader;
-        reader.setContentHandler( &handler );
         reader.parse( source );
     }
     return 0;
